[PATCH] D37273: [sanitizer_common][Fuchsia] Update Fuchsia sanitizer markup

Petr Hosek via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Tue Sep 5 17:02:19 PDT 2017


This revision was automatically updated to reflect the committed changes.
Closed by commit rL312596: [sanitizer_common][Fuchsia] Update Fuchsia sanitizer markup (authored by phosek).

Changed prior to commit:
  https://reviews.llvm.org/D37273?vs=113147&id=113936#toc

Repository:
  rL LLVM

https://reviews.llvm.org/D37273

Files:
  compiler-rt/trunk/lib/sanitizer_common/sanitizer_coverage_fuchsia.cc
  compiler-rt/trunk/lib/sanitizer_common/sanitizer_symbolizer_fuchsia.cc


Index: compiler-rt/trunk/lib/sanitizer_common/sanitizer_symbolizer_fuchsia.cc
===================================================================
--- compiler-rt/trunk/lib/sanitizer_common/sanitizer_symbolizer_fuchsia.cc
+++ compiler-rt/trunk/lib/sanitizer_common/sanitizer_symbolizer_fuchsia.cc
@@ -25,8 +25,8 @@
 // symbol names, embedded in Fuchsia's symbolization markup format.
 // Fuchsia's logging infrastructure emits enough information about
 // process memory layout that a post-processing filter can do the
-// symbolization and pretty-print the markup.
-// TODO(mcgrathr): URL to markup format document
+// symbolization and pretty-print the markup.  See the spec at:
+// https://fuchsia.googlesource.com/magenta/+/master/docs/symbolizer_markup.md
 
 // This is used by UBSan for type names, and by ASan for global variable names.
 constexpr const char *kFormatDemangle = "{{{symbol:%s}}}";


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D37273.113936.patch
Type: text/x-patch
Size: 2064 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20170906/73428243/attachment.bin>


More information about the llvm-commits mailing list
Index: compiler-rt/trunk/lib/sanitizer_common/sanitizer_coverage_fuchsia.cc
===================================================================
--- compiler-rt/trunk/lib/sanitizer_common/sanitizer_coverage_fuchsia.cc
+++ compiler-rt/trunk/lib/sanitizer_common/sanitizer_coverage_fuchsia.cc
@@ -96,10 +96,13 @@
       __sanitizer_publish_data(kSancovSinkName, vmo_);
       vmo_ = MX_HANDLE_INVALID;
 
-      // This will route to __sanitizer_log_write, which will ensure
-      // that information about shared libraries is written out.
-      Printf("SanitizerCoverage: published '%s' with up to %u PCs\n", vmo_name_,
-             next_index_ - 1);
+      // This will route to __sanitizer_log_write, which will ensure that
+      // information about shared libraries is written out.  This message
+      // uses the `dumpfile` symbolizer markup element to highlight the
+      // dump.  See the explanation for this in:
+      // https://fuchsia.googlesource.com/magenta/+/master/docs/symbolizer_markup.md
+      Printf("SanitizerCoverage: {{{dumpfile:%s:%s}}} with up to %u PCs\n",
+             kSancovSinkName, vmo_name_, next_index_ - 1);
     }
   }
 